@@ -28,13 +28,13 @@ from drf_spectacular.plumbing import (
     ComponentRegistry, ResolvedComponent, UnableToProceedError, append_meta,
     assert_basic_serializer, build_array_type, build_basic_type, build_choice_field,
     build_examples_list, build_generic_type, build_listed_example_value, build_media_type_object,
-    build_mocked_view, build_object_type, build_parameter_type, error, follow_field_source,
-    follow_model_field_lookup, force_instance, get_doc, get_list_serializer, get_type_hints,
-    get_view_model, is_basic_serializer, is_basic_type, is_field, is_list_serializer,
-    is_list_serializer_customized, is_patched_serializer, is_serializer,
-    is_trivial_string_variation, modify_media_types_for_versioning, resolve_django_path_parameter,
-    resolve_regex_path_parameter, resolve_type_hint, safe_ref, sanitize_specification_extensions,
-    warn, whitelisted,
+    build_mocked_view, build_object_type, build_parameter_type, build_serializer_context, error,
+    filter_supported_arguments, follow_field_source, follow_model_field_lookup, force_instance,
+    get_doc, get_list_serializer, get_type_hints, get_view_model, is_basic_serializer,
+    is_basic_type, is_field, is_list_serializer, is_list_serializer_customized,
+    is_patched_serializer, is_serializer, is_trivial_string_variation,
+    modify_media_types_for_versioning, resolve_django_path_parameter, resolve_regex_path_parameter,
+    resolve_type_hint, safe_ref, sanitize_specification_extensions, warn, whitelisted,
 )
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.types import OpenApiTypes
@@ -312,7 +312,10 @@ class AutoSchema(ViewInspector):
 
             security_requirements = scheme.get_security_requirement(self)
             if security_requirements is not None:
-                auths.append(security_requirements)
+                if isinstance(security_requirements, dict):
+                    auths.append(security_requirements)
+                else:
+                    auths.extend(security_requirements)
 
             if isinstance(scheme.name, str):
                 names, definitions = [scheme.name], [scheme.get_security_definition(self)]
@@ -664,9 +667,17 @@ class AutoSchema(ViewInspector):
                 if isinstance(field.parent, serializers.ManyRelatedField):
                     model = field.parent.parent.Meta.model
                     source = field.parent.source.split('.')
-                else:
+                elif hasattr(field.parent, 'Meta'):
                     model = field.parent.Meta.model
                     source = field.source.split('.')
+                else:
+                    warn(
+                        f'Could not derive type for under-specified PrimaryKeyRelatedField '
+                        f'"{field.field_name}". The serializer has no associated model (Meta class) '
+                        f'and this particular field has no type without a model association. Consider '
+                        f'changing the field or adding a Meta class. defaulting to string.'
+                    )
+                    return append_meta(build_basic_type(OpenApiTypes.STR), meta)
 
                 # estimates the relating model field and jumps to it's target model PK field.
                 # also differentiate as source can be direct (pk) or relation field (model).
@@ -942,6 +953,10 @@ class AutoSchema(ViewInspector):
     def _map_basic_serializer(self, serializer, direction):
         assert_basic_serializer(serializer)
         serializer = force_instance(serializer)
+        # serializers provided through @extend_schema will not receive the mock context
+        # via _get_serializer(). Establish behavioral symmetry for those use-cases.
+        if not serializer.context:
+            serializer.context.update(build_serializer_context(self.view))
         required = set()
         properties = {}
 
@@ -1086,20 +1101,21 @@ class AutoSchema(ViewInspector):
 
     def _get_serializer(self):
         view = self.view
+        context = build_serializer_context(view)
         try:
             if isinstance(view, GenericAPIView):
                 # try to circumvent queryset issues with calling get_serializer. if view has NOT
                 # overridden get_serializer, its safe to use get_serializer_class.
                 if view.__class__.get_serializer == GenericAPIView.get_serializer:
-                    return view.get_serializer_class()()
-                return view.get_serializer()
+                    return view.get_serializer_class()(context=context)
+                return view.get_serializer(context=context)
             elif isinstance(view, APIView):
                 # APIView does not implement the required interface, but be lenient and make
                 # good guesses before giving up and emitting a warning.
                 if callable(getattr(view, 'get_serializer', None)):
-                    return view.get_serializer()
+                    return view.get_serializer(context=context)
                 elif callable(getattr(view, 'get_serializer_class', None)):
-                    return view.get_serializer_class()()
+                    return view.get_serializer_class()(context=context)
                 elif hasattr(view, 'serializer_class'):
                     return view.serializer_class
                 else:
@@ -1422,11 +1438,17 @@ class AutoSchema(ViewInspector):
 
         return result
 
-    def _get_serializer_name(self, serializer, direction):
+    def _get_serializer_name(self, serializer, direction, bypass_extensions=False):
         serializer_extension = OpenApiSerializerExtension.get_match(serializer)
-        if serializer_extension and serializer_extension.get_name():
-            # library override mechanisms
-            name = serializer_extension.get_name()
+        if serializer_extension and not bypass_extensions:
+            custom_name = serializer_extension.get_name(**filter_supported_arguments(
+                serializer_extension.get_name, auto_schema=self, direction=direction
+            ))
+        else:
+            custom_name = None
+
+        if custom_name:
+            name = custom_name
         elif has_override(serializer, 'component_name'):
             name = get_override(serializer, 'component_name')
         elif getattr(getattr(serializer, 'Meta', None), 'ref_name', None) is not None:
@@ -1457,13 +1479,13 @@ class AutoSchema(ViewInspector):
 
         return name
 
-    def resolve_serializer(self, serializer, direction) -> ResolvedComponent:
+    def resolve_serializer(self, serializer, direction, bypass_extensions=False) -> ResolvedComponent:
         assert_basic_serializer(serializer)
         serializer = force_instance(serializer)
 
         with add_trace_message(serializer.__class__.__name__):
             component = ResolvedComponent(
-                name=self._get_serializer_name(serializer, direction),
+                name=self._get_serializer_name(serializer, direction, bypass_extensions),
                 type=ResolvedComponent.SCHEMA,
                 object=serializer,
             )
@@ -1471,7 +1493,7 @@ class AutoSchema(ViewInspector):
                 return self.registry[component]  # return component with schema
 
             self.registry.register(component)
-            component.schema = self._map_serializer(serializer, direction)
+            component.schema = self._map_serializer(serializer, direction, bypass_extensions)
 
             discard_component = (
                 # components with empty schemas serve no purpose
