@@ -1275,3 +1275,17 @@ def build_listed_example_value(value: Any, paginator, direction):
             f"provide example values themselves. Using the plain example value as fallback."
         )
         return value
+
+
+def filter_supported_arguments(func, **kwargs):
+    sig = inspect.signature(func)
+    return {
+        arg: val for arg, val in kwargs.items() if arg in sig.parameters
+    }
+
+
+def build_serializer_context(view) -> typing.Dict[str, Any]:
+    try:
+        return view.get_serializer_context()
+    except:  # noqa
+        return {'request': view.request}
